@@ -6,6 +6,7 @@ import pandas as pd
 import time
 from gmat.process_plink.process_plink import impute_geno
 from pysnptools.snpreader import Bed
+from tqdm import tqdm
 
 
 def output_mat(mat, id_df, out_file, out_fmt):
@@ -60,7 +61,7 @@ def agmat(bed_file, out_file, inv=False, out_fmt='mat', npart=10, small_val=0.00
     cpu_t0 = time.process_time()
     scale = 0.0
     kin = np.zeros((num_id, num_id))
-    for i in range(npart):
+    for i in tqdm(range(npart)):
         snp_mat = snp_on_disk[:, snp_index[i]:snp_index[i+1]].read().val
         if np.any(np.isnan(snp_mat)):
             snp_mat = impute_geno(snp_mat)
@@ -123,7 +124,7 @@ def dgmat_as(bed_file, out_file, inv=False, out_fmt='mat', npart=10, small_val=0
     cpu_t0 = time.process_time()
     scale = 0.0
     kin = np.zeros((num_id, num_id))
-    for i in range(npart):
+    for i in tqdm(range(npart)):
         snp_mat = snp_on_disk[:, snp_index[i]:snp_index[i + 1]].read().val
         if np.any(np.isnan(snp_mat)):
             snp_mat = impute_geno(snp_mat)
